@@ -11,6 +11,7 @@ import numpy as np
 import pandas as pd
 from dask import delayed
 from prompt_toolkit.shortcuts import input_dialog
+from dask.distributed.protocol.serialize import register_generic
 
 from ..base import (
     TILE_INDEX_STR,
@@ -28,6 +29,11 @@ __all__ = ["LatticeScopeDataset", "LatticeScopeTiledDataset"]
 
 logger = logging.getLogger("utoolbox.io.dataset")
 
+# ensure dask knows how to serialize/deserialize imageio result
+register_generic(imageio.core.util.Array)
+
+# internally coded camera pixel size
+# FIXME provide an external lookup source
 PIXEL_SIZE_LUT = {"Orca4.0": 6.5}
 
 
@@ -78,9 +84,7 @@ class LatticeScopeDataset(
                 arrays = []
                 for part_uri, part_shape in zip(uri, self._fragmented_shapes):
                     part_array = da.from_delayed(
-                        delayed(imageio.volread, pure=True)(part_uri),
-                        part_shape,
-                        dtype,
+                        delayed(imageio.volread, pure=True)(part_uri), part_shape, dtype
                     )
                     arrays.append(part_array)
                 # fragments are 3D-only, we concat them at the slowest axis
